diff --git a/addons/im_livechat_mail_bot/__manifest__.py b/addons/im_livechat_mail_bot/__manifest__.py
index 7c1906b78ea..28c3c54a25f 100644
--- a/addons/im_livechat_mail_bot/__manifest__.py
+++ b/addons/im_livechat_mail_bot/__manifest__.py
@@ -2,10 +2,10 @@
# Part of Odoo. See LICENSE file for full copyright and licensing details.
{
- 'name': 'Odoobot for livechat',
+ 'name': 'OdooBot for livechat',
'version': '1.0',
'category': 'Discuss',
- 'summary': 'Add livechat support for odoobot',
+ 'summary': 'Add livechat support for OdooBot',
'description': "",
'website': 'https://www.odoo.com/page/discuss',
'depends': ['mail_bot', 'im_livechat'],
diff --git a/addons/mail_bot/__manifest__.py b/addons/mail_bot/__manifest__.py
index eef58113154..37f769a005c 100644
--- a/addons/mail_bot/__manifest__.py
+++ b/addons/mail_bot/__manifest__.py
@@ -2,10 +2,10 @@
# Part of Odoo. See LICENSE file for full copyright and licensing details.
{
- 'name': 'Odoobot',
+ 'name': 'OdooBot',
'version': '1.0',
'category': 'Discuss',
- 'summary': 'Add Odoobot in discussions',
+ 'summary': 'Add OdooBot in discussions',
'description': "",
'website': 'https://www.odoo.com/page/discuss',
'depends': ['mail'],
diff --git a/addons/mail_bot/models/mail_bot.py b/addons/mail_bot/models/mail_bot.py
index 92d2272a760..0d311922cc1 100644
--- a/addons/mail_bot/models/mail_bot.py
+++ b/addons/mail_bot/models/mail_bot.py
@@ -75,7 +75,7 @@ class MailBot(models.AbstractModel):
_("Sorry I'm sleepy. Or not! Maybe I'm just trying to hide my unawareness of human language...
I can show you features if you write")+ ": '"+_('start the tour')+"'.",
])
elif self._is_bot_pinged(values):
- return random.choice([_("Yep, Odoobot is in the place!"), _("Pong.")])
+ return random.choice([_("Yep, OdooBot is in the place!"), _("Pong.")])
return False
def _body_contains_emoji(self, body):
diff --git a/addons/mail_bot/models/res_users.py b/addons/mail_bot/models/res_users.py
index 2905e3d8f5e..226667f6ae7 100644
--- a/addons/mail_bot/models/res_users.py
+++ b/addons/mail_bot/models/res_users.py
@@ -14,4 +14,4 @@ class Users(models.Model):
('onboarding_ping', 'Onboarding ping'),
('idle', 'Idle'),
('disabled', 'Disabled'),
- ], string="Odoobot Status", readonly=True, required=True, default="not_initialized") # keep track of the state: correspond to the code of the last message sent
+ ], string="OdooBot Status", readonly=True, required=True, default="not_initialized") # keep track of the state: correspond to the code of the last message sent
diff --git a/addons/test_mail/tests/test_odoobot.py b/addons/test_mail/tests/test_odoobot.py
index ff74fcc1083..9dca4884981 100644
--- a/addons/test_mail/tests/test_odoobot.py
+++ b/addons/test_mail/tests/test_odoobot.py
@@ -33,7 +33,7 @@ class TestOdoobot(BaseFunctionalTest, MockEmails, TestRecipients):
self.assertNextMessage(
self.test_record_employe.with_context({'mail_post_autofollow': True}).message_post(**kwargs),
sender=self.odoobot,
- answer=["Yep, Odoobot is in the place!"]
+ answer=["Yep, OdooBot is in the place!"]
)
# Odoobot should not be a follower but user_employee and user_admin should
follower = self.test_record.message_follower_ids.mapped('partner_id')
diff --git a/addons/mail/static/src/js/models/messages/message.js b/addons/mail/static/src/js/models/messages/message.js
index 881a5ae2c97..c733b74f347 100644
--- a/addons/mail/static/src/js/models/messages/message.js
+++ b/addons/mail/static/src/js/models/messages/message.js
@@ -560,7 +560,7 @@ var Message = AbstractMessage.extend(Mixins.EventDispatcherMixin, ServicesMixin
*/
_getAuthorName: function () {
if (this._isOdoobotAuthor()) {
- return "Odoobot";
+ return "OdooBot";
}
return this._super.apply(this, arguments);
},
@@ -572,7 +572,7 @@ var Message = AbstractMessage.extend(Mixins.EventDispatcherMixin, ServicesMixin
return this._moduleIcon;
},
/**
* State if the author of this message is Odoobot
* This is the default author for transient messages.
*
* @private
@@ -572,7 +572,7 @@ var Message = AbstractMessage.extend(Mixins.EventDispatcherMixin, ServicesMixin
},
/**
- * State if the author of this message is Odoobot
+ * State if the author of this message is OdooBot
* This is the default author for transient messages.
*
diff --git a/addons/mail/static/src/js/services/mail_manager.js b/addons/mail/static/src/js/services/mail_manager.js
index 49d7fc9c45e..5be12c6e934 100644
--- a/addons/mail/static/src/js/services/mail_manager.js
+++ b/addons/mail/static/src/js/services/mail_manager.js
@@ -254,7 +254,7 @@ var MailManager = AbstractService.extend({
return this._moderatedChannelIDs || [];
},
/**
* Get the Odoobot ID, which is the default authorID for transient messages
*
* @returns {string}
*/
@@ -831,7 +831,7 @@ var MailManager = AbstractService.extend({
(filter === 'mailbox_inbox' || !filter)
) {
elems.push({
- title: _t("Odoobot has a request for you"),
+ title: _t("OdooBot has a request"),
imageSRC: "/mail/static/src/img/odoobot.png",
status: 'bot',
body: _t("Enable desktop notifications to chat"),
@@ -254,7 +254,7 @@ var MailManager = AbstractService.extend({
},
/**
- * Get the Odoobot ID, which is the default authorID for transient messages
+ * Get the OdooBot ID, which is the default authorID for transient messages
*
* @returns {string}